==> web-jersey-5.8.0-sources.jar: org/smallmind/web/jersey/json/FormattedWebApplicationException.java <==
/*
 * Copyright (c) 2007 through 2024 David Berkman
 *
 * This file is part of the SmallMind Code Project.
 *
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 *
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * ...or...
 *
 * 2) The terms of the Apache License, Version 2.0.
 *
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 *
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.web.jersey.json;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import org.smallmind.web.json.scaffold.fault.Fault;

public class FormattedWebApplicationException extends WebApplicationException {

  public FormattedWebApplicationException (Response.Status status, String message, Object... args) {

    this(status, new Fault(message == null ? null : String.format(message, args)));
  }

  public FormattedWebApplicationException (Response.Status status, Throwable throwable) {

    this(status, new Fault(throwable, false));
  }

  public FormattedWebApplicationException (Response.Status status, Fault fault) {

    super(fault.getMessage(), Response.status(status).type(MediaType.APPLICATION_JSON_TYPE).entity(fault).build());
  }
}

==> web-jersey-6.1.0-sources.jar: org/smallmind/web/jersey/json/FormattedWebApplicationException.java <==
/*
 * Copyright (c) 2007 through 2024 David Berkman
 *
 * This file is part of the SmallMind Code Project.
 *
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 *
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * ...or...
 *
 * 2) The terms of the Apache License, Version 2.0.
 *
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 *
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.web.jersey.json;

import jakarta.ws.rs.WebApplicationException;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;
import org.smallmind.web.json.scaffold.fault.Fault;

public class FormattedWebApplicationException extends WebApplicationException {

  public FormattedWebApplicationException (Response.Status status, String message, Object... args) {

    this(status, new Fault(message == null ? null : String.format(message, args)));
  }

  public FormattedWebApplicationException (Response.Status status, Throwable throwable) {

    this(status, new Fault(throwable, false));
  }

  public FormattedWebApplicationException (Response.Status status, Fault fault) {

    super(fault.getMessage(), Response.status(status).type(MediaType.APPLICATION_JSON_TYPE).entity(fault).build());
  }
}
